| summary.ctpfit | R Documentation |
Summary method for ctpfit objects
## S3 method for class 'ctpfit'
summary(object, ...)
object |
A ctpfit object |
... |
Additional arguments (ignored) |
Invisibly returns the original fitted model object. The function is called for its side effects, producing a formatted summary of parameter estimates, moments, and goodness-of-fit diagnostics.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.