| zmctp-package | R Documentation |
The zmctp package extends the Complex Triparametric Pearson (CTP) distribution with zero-modified versions for handling overdispersed count data, particularly when the parameter b approaches zero.
Main functions:
dctp, pctp, qctp,
rctp - CTP distribution functions
dzictp, pzictp, qzictp,
rzictp - Zero-Modified CTP distribution functions
ctp.fit - Fit CTP model
zictp.fit - Fit Zero-Modified CTP model
Maintainer: Rasheedat Oladoja roladoja@ttu.edu (ORCID)
Useful links:
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.