| mean_ctp | R Documentation |
Theoretical moments of the CTP distribution
mean_ctp(a, b, gama)
var_ctp(a, b, gama)
skew_ctp(a, b, gama)
a, b, gama |
CTP parameters. |
These functions do not validate that the parameter constraints required
for a given moment to exist are satisfied (e.g. gama > 2*a+2 for
the variance, gama > 2*a+3 for the skewness). Outside these
regions the returned value may be Inf, NaN, or negative;
see dctp for the corresponding existence warnings applied
at the density level. See mode_ctp for the mode, including
its tie-case handling.
mean_ctp(a = 1, b = 0.5, gama = 6)
var_ctp(a = 1, b = 0.5, gama = 6)
skew_ctp(a = 1, b = 0.5, gama = 6)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.